# Load library
from vaderSentiment.vaderSentiment import SentimentIntensityAnalyzer
from selenium.webdriver.chrome.options import Options
from nltk.tokenize import RegexpTokenizer
from nltk.tokenize import word_tokenize
from nltk.corpus import stopwords
from selenium import webdriver
from textblob import TextBlob
from bs4 import BeautifulSoup
from datetime import datetime
import chromedriver_binary
from requests import get
import pandas as pd
import time
import nltk
import sys
import
# You will have to download the set of stop words the first time
nltk.download('stopwords')



from twitter.utils import *

class tweets:

    """
    Collects tweets of the social-media content in Twitter when hashtag is given.
    :param tweets: Unique identification keyword for every social-media tweets in Twitter.
    :returns: Returns all the tweets.
    """

    def __init__(self, keyword):
        start_time = datetime.now()
        options = Options()
        options.headless = True
        options=options
        browser = webdriver.Chrome(options=options)
        browser.get("https://twitter.com/search?q=" + keyword)

        while browser.find_element_by_tag_name('div'):
            browser.execute_script("window.scrollTo(0, document.body.scrollHeight);")
            time_delta = datetime.now() - start_time
            sys.stdout.write('\r' + str("calculating time") + "  " + str(time_delta.seconds) +  "  " + "seconds taken to parse all the tweets from twitter" + '\r')
            sys.stdout.flush()
            if time_delta.seconds >= 150:
                break

        soup = BeautifulSoup(browser.page_source, 'lxml')
        browser.quit()

        tweets_count = soup.select('.TweetTextSize')
        sys.stdout.write('\r' + "\n" + str("total tweets are") + " : " + str(len(tweets_count)) + '\r')
        sys.stdout.flush()

        tokenizer = RegexpTokenizer(r'\w+')
        stop_words = stopwords.words('english')

        analyser = SentimentIntensityAnalyzer()
        neu_sum, neg_sum, compound_sum, pos_sum, count = 0,0,0,0,0
        def cleaning_text(text):
            text = re.sub(r'\b(?:(?:https?|ftp)://)?\w[\w-]*(?:\.[\w-]+)+\S*', ' ', text.lower())
            words = re.findall(r'[a-zA-Z]+', text)
            text = ' '.join([word for word in tokenizer.tokenize(' '.join(words)) if word not in stop_words])
            return text

        self.original_tweets = [' '.join(item.text.split()) for item in tweets_count]
        self.cleaned_tweets = [cleaning_text(tweet) for tweet in tweets_count]
        sentiment_score = [analyser.polarity_scores(self.cleaned_tweets[i])['compound'] for i in range(len(self.cleaned_tweets))]
        polarity_score = [analyser.polarity_scores(self.cleaned_tweets[i]) for i in range(len(self.cleaned_tweets))]

        sentiment = []
        for item in self.cleaned_tweets:
            analysis = TextBlob(' '.join(item.text.split()))
            # set sentiment
            if analysis.sentiment.polarity > 0:
                sentiment.append('positive')
            elif analysis.sentiment.polarity == 0:
                sentiment.append('neutral')
            else:
                sentiment.append('negative')

        for i in range(len(self.cleaned_tweets)):
            count += 1
            score = analyser.polarity_scores(self.cleaned_tweets[i])
            neu_sum += score['neu']
            neg_sum += score['neg']
            pos_sum += score['pos']

        if count:
            self.final_sentiment_scores = {"neu" : round(neu_sum / count, 3), "neg" : round(neg_sum / count, 3), "pos" : round(pos_sum / count, 3), "compound" : round(compound_sum / count, 3)}
        else:
            self.final_sentiment_scores = None

        container = soup.select('.content')
        names = [item.select_one('strong.fullname').text for item in container]
        usernames = [item.select_one('span.username').text for item in container]
        user_ids = [item.select_one('a.account-group')['data-user-id'] for item in container]
        conversation_ids = [item.select_one('a.tweet-timestamp')['data-conversation-id'] for item in container]
        dates = [item.select_one('a.tweet-timestamp')['title'] for item in container]

        self.tweets_df = pd.DataFrame({'name' : names,
                                       'username' : usernames,
                                       'user_id' : user_ids,
                                       'conversation_id' : conversation_ids,
                                       'date' : dates,
                                       'tweets' : self.original_tweets,
                                       'cleaned_tweets' : self.cleaned_tweets,
                                       'sentiment' : sentiment,
                                       'sentiment_score' : sentiment_score,
                                       'polarity_scorce' : polarity_score})



"""A setuptools based setup module.
See:
https://packaging.python.org/guides/distributing-packages-using-setuptools/
https://santhoshse7en.github.io/tweety/
"""
# -*- encoding: utf-8 -*-
from __future__ import absolute_import
from __future__ import print_function

# Always prefer setuptools over distutils
import setuptools

keywords = ['twitter', "tweets", "without-api", "twitter_scraper", 'selenium', 'vaderSentiment',
'bs4', 'textblob', 'twitter_sentiment', "sentiment_analysis", 'twitter_analysis']

setuptools.setup(
    name="tweety",
    version="0.0.7",
    author="M Santhosh Kumar",
    author_email="santhoshse7en@gmail.com",
    description="Python package which to access the Twitter database without API",
    long_description=open('README.md').read(),
    long_description_content_type="text/markdown",
    url="https://santhoshse7en.github.io/tweety/",
    keywords = keywords,
    install_requires=['beautifulsoup4', 'pandas', 'selenium', 'vaderSentiment', 'textblob', 'chromedriver-binary==74.0.3729.6.0'],
    packages=setuptools.find_packages(),
    classifiers=['Development Status :: 4 - Beta',
              'Intended Audience :: End Users/Desktop',
              'Intended Audience :: Developers',
              'Intended Audience :: System Administrators',
              'License :: OSI Approved :: MIT License',
              'Operating System :: OS Independent',
              'Programming Language :: Python',
              'Topic :: Communications :: Email',
              'Topic :: Office/Business',
              'Topic :: Software Development :: Bug Tracking',
              ],
)
